==> qtjambi-quick-debuginfo-linux-x64-6.6.0.jar: sources/QtJambiQuick/QQuickTextDocument_shell.h <==
#ifndef QQUICKTEXTDOCUMENT_SHELL_H
#define QQUICKTEXTDOCUMENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtQuick/qquicktextdocument.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qtextdocument.h>
#include <QtQuick/qquickitem.h>
#include <QtJambi/RegistryAPI>


class QQuickTextDocument_shell : public QQuickTextDocument, public QtJambiShellInterface
{
public:
    QQuickTextDocument_shell(QQuickItem* parent0);
    ~QQuickTextDocument_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickTextDocument_access : public QQuickTextDocument
{
};

#endif // QQUICKTEXTDOCUMENT_SHELL_H

==> qtjambi-quick-debuginfo-linux-x64-6.7.2.jar: sources/QtJambiQuick/QQuickTextDocument_shell.h <==
#ifndef QQUICKTEXTDOCUMENT_SHELL_H
#define QQUICKTEXTDOCUMENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQuick/qquicktextdocument.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtGui/qtextdocument.h>
#include <QtQuick/qquickitem.h>
#include <QtJambi/RegistryAPI>


class QQuickTextDocument_shell : public QQuickTextDocument, public QtJambiShellInterface
{
public:
    QQuickTextDocument_shell(QQuickItem* parent0);
    ~QQuickTextDocument_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QQuickTextDocument_mshell;
    friend class QQuickTextDocument_oshell;
};


class QQuickTextDocument_mshell : public QQuickTextDocument_shell
{
public:
    using QQuickTextDocument_shell::QQuickTextDocument_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QQuickTextDocument_oshell : public QQuickTextDocument_mshell
{
public:
    using QQuickTextDocument_mshell::QQuickTextDocument_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickTextDocument_access : public QQuickTextDocument
{
};

#endif // QQUICKTEXTDOCUMENT_SHELL_H
